@@ -1282,7 +1282,8 @@ source_added_cb (GrlRegistry *registry,
 		if (source_is_recent (source)) {
 			browse (self, self->priv->recent_model,
 				NULL, source, NULL, -1);
-			monitor = TRUE;
+			if (g_str_equal (id, "grl-tracker-source") == FALSE)
+				monitor = TRUE;
 		} else if (!source_is_browse_blacklisted (source)) {
 			const GdkPixbuf *icon;
 
@@ -1297,12 +1298,12 @@ source_added_cb (GrlRegistry *registry,
 							   MODEL_RESULTS_IS_PRETHUMBNAIL, TRUE,
 							   MODEL_RESULTS_CAN_REMOVE, can_remove (source, NULL),
 							   -1);
-			monitor = TRUE;
+
+			if (g_str_equal (id, "grl-filesystem") == FALSE)
+				monitor = TRUE;
 		}
 
-		if (monitor &&
-		    (ops & GRL_OP_NOTIFY_CHANGE) &&
-		    g_str_equal (id, "grl-filesystem") == FALSE) {
+		if (monitor && (ops & GRL_OP_NOTIFY_CHANGE)) {
 			grl_source_notify_change_start (source, NULL);
 			g_signal_connect (G_OBJECT (source), "content-changed",
 					  G_CALLBACK (content_changed_cb), self);
@@ -2487,6 +2488,8 @@ totem_grilo_finalize (GObject *object)
 void
 totem_grilo_start (TotemGrilo *self)
 {
+	g_debug ("TotemGrilo: Resuming videos thumbnailing");
+
 	totem_grilo_resume_icon_thumbnailing ();
 
 	if (self->priv->plugins_loaded)
@@ -2501,6 +2504,7 @@ totem_grilo_start (TotemGrilo *self)
 void
 totem_grilo_pause (TotemGrilo *self)
 {
+	g_debug ("TotemGrilo: Pausing videos thumbnailing");
 	totem_grilo_pause_icon_thumbnailing ();
 }
 
