@@ -36,6 +36,7 @@
 #include <gdk/gdk.h>
 #include <totem-pl-parser.h>
 
+#include <locale.h>
 #include <errno.h>
 #include <unistd.h>
 #include <string.h>
@@ -891,6 +892,11 @@ int main (int argc, char *argv[])
 	const char *input, *output;
 	ThumbApp app;
 
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
 	context = g_option_context_new ("Thumbnail movies");
 	options = gst_init_get_option_group ();
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
